@@ -1,5 +1,5 @@
 /*
- * DVD code copyright (C) 2002, 2003 Jan Panteltje <panteltje@yahoo.com>,
+ * DVD code copyright (C) 2002, 2003, 20004, always Jan Panteltje <panteltje@yahoo.com>,
  * original CVD and SVCD code by unknown author.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -24,7 +24,7 @@
 
 #define _FILE_OFFSET_BITS   64
 
-#define VERSION "0.5.1"
+#define VERSION "0.5.2"
 
 #define SUB_BUFFER_MAX		53220 
 
@@ -161,10 +161,12 @@ typedef struct
 unsigned char bb, bc;
 unsigned char *sub, *cbuf;
 unsigned char *img, *fimg;
-unsigned char nbuf[256];
+//unsigned char nbuf[256];
+char nbuf[256];
+
 FILE *fds;
 
-unsigned int subo, x0, y0, xd, yd, x0_, y0_, xd_, yd_;
+static unsigned int subo, x0, y0, xd, yd, x0_, y0_, xd_, yd_; // -Wall, y0 is a build in function, static reduces its scope to this source file
 unsigned int iline, progr, skip;
 int sd, sd_;
 int tofs, spts, nspts, lvpts;
@@ -607,7 +609,8 @@ return a;
 
 void rns()
 {
-unsigned char lbuf[256 + 80];
+//unsigned char lbuf[256 + 80];
+char lbuf[256 + 80];
 int a,b, i;
 
 if(debug_flag)
@@ -635,13 +638,18 @@ if ((lbuf[0] == '#') || (lbuf[0] == ' ') || (lbuf[0] == 0)) goto lns;
  
 /* get bitmap filename */ 
 a = 0;
-while(lbuf[a]  &&  (lbuf[a] != 32)  &&  (lbuf[a] != 9)) nbuf[a++] = lbuf[a];
+while(lbuf[a]  &&  (lbuf[a] != 32)  &&  (lbuf[a] != 9))
+	{
+	nbuf[a] = lbuf[a];
+	a++;
+	}
+
 /* string termination */
 nbuf[a] = 0;
 
 /* get start time */
 while((lbuf[a])  &&  !((lbuf[a] > 47)  &&  (lbuf[a] < 58))) a++;
- nspts = atoi(lbuf + a) * 60 * 60 * 90000; a += 3;
+nspts = atoi(lbuf + a) * 60 * 60 * 90000; a += 3;
 nspts += atoi(lbuf + a) * 60 * 90000; a += 3;
 nspts += atoi(lbuf + a) * 90000; a += 3;
 nspts += atoi(lbuf + a) * 900; a += 2;
@@ -954,8 +962,14 @@ if (!optimize)
 		} 
 	a = 0;
 	for(y = 0; (y < yd) &&  (y < yd); y++) 
-		for(x = 0; (x < xd)  &&  (x < xd); x++) fimg[a++] = img[a];
-    
+		{
+		for(x = 0; (x < xd)  &&  (x < xd); x++)
+			{
+			fimg[a] = img[a];
+			a++;
+			}
+		}    
+
 //#define P_TEST2
 #ifdef P_TEST2 
  for(a = 0; a < 4; a++)
@@ -1112,7 +1126,9 @@ int main(int argc,char **argv)
 int fdi, fdo;
 unsigned int q, c, a, i, j, k, gts, pts, muxrate, sector_size, frame, lps;
 unsigned short int b, vss, subno;
-unsigned char cc, seq, psbuf[psbufs], substr, *nptr[3], ncnt;
+unsigned char cc, seq, psbuf[psbufs], substr;
+char *nptr[3];
+int ncnt;
 int sub_size;
 int bytes_send;
 unsigned short int header_size;
@@ -1223,7 +1239,7 @@ img = malloc(maxx * maxy);
 fimg = malloc(maxx * maxy);
  
 
-fprintf(stderr, "submux-dvd-%s copyright 2003 Jan Panteltje\n", VERSION);
+fprintf(stderr, "submux-dvd-%s copyright 2002-always Jan Panteltje\n", VERSION);
 
 if (argc<4)
 	{
@@ -1644,7 +1660,10 @@ exit(1);
 			if(sub_size > max_sub_size)
 				{
 				max_sub_size = sub_size;
-				fprintf(stderr, "max_sub_size=%d\n", max_sub_size);
+				if(debug > 0)
+					{
+					fprintf(stderr, "max_sub_size=%d\n", max_sub_size);
+					}
 				}
 
 			seq = 0;
@@ -2851,8 +2870,10 @@ for(y = 0; y < yd; y++)
 	{
 	for(x = 0; x < xd; x++)
 		{
-		img[a++] = lpal[ img[a] ].t;
+		img[a] = lpal[ img[a] ].t;
 //		img[a++] = pal[ img[a] ].t;
+
+		a++;
 		}
 	}
 
